using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using TransmissionRssManager.Core;

namespace TransmissionRssManager.Api.Controllers
{
    [ApiController]
    [Route("api/[controller]")]
    public class ConfigController : ControllerBase
    {
        private readonly ILogger<ConfigController> _logger;
        private readonly IConfigService _configService;

        public ConfigController(
            ILogger<ConfigController> logger,
            IConfigService configService)
        {
            _logger = logger;
            _configService = configService;
        }

        [HttpGet]
        public IActionResult GetConfig()
        {
            var config = _configService.GetConfiguration();
            
            // Create a sanitized config without sensitive information
            var sanitizedConfig = new
            {
                transmission = new
                {
                    host = config.Transmission.Host,
                    port = config.Transmission.Port,
                    useHttps = config.Transmission.UseHttps,
                    hasCredentials = !string.IsNullOrEmpty(config.Transmission.Username)
                },
                autoDownloadEnabled = config.AutoDownloadEnabled,
                checkIntervalMinutes = config.CheckIntervalMinutes,
                downloadDirectory = config.DownloadDirectory,
                mediaLibraryPath = config.MediaLibraryPath,
                postProcessing = config.PostProcessing
            };
            
            return Ok(sanitizedConfig);
        }

        [HttpPut]
        public async Task<IActionResult> UpdateConfig([FromBody] AppConfig config)
        {
            var currentConfig = _configService.GetConfiguration();
            
            // If password is empty, keep the existing one
            if (string.IsNullOrEmpty(config.Transmission.Password) && !string.IsNullOrEmpty(currentConfig.Transmission.Password))
            {
                config.Transmission.Password = currentConfig.Transmission.Password;
            }
            
            await _configService.SaveConfigurationAsync(config);
            return Ok(new { success = true });
        }
    }
}