using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using TransmissionRssManager.Core;

namespace TransmissionRssManager.Api.Controllers
{
    [ApiController]
    [Route("api/[controller]")]
    public class FeedsController : ControllerBase
    {
        private readonly ILogger<FeedsController> _logger;
        private readonly IRssFeedManager _rssFeedManager;

        public FeedsController(
            ILogger<FeedsController> logger,
            IRssFeedManager rssFeedManager)
        {
            _logger = logger;
            _rssFeedManager = rssFeedManager;
        }

        [HttpGet]
        public async Task<IActionResult> GetFeeds()
        {
            var feeds = await _rssFeedManager.GetFeedsAsync();
            return Ok(feeds);
        }

        [HttpGet("items")]
        public async Task<IActionResult> GetAllItems()
        {
            var items = await _rssFeedManager.GetAllItemsAsync();
            return Ok(items);
        }

        [HttpGet("matched")]
        public async Task<IActionResult> GetMatchedItems()
        {
            var items = await _rssFeedManager.GetMatchedItemsAsync();
            return Ok(items);
        }

        [HttpPost]
        public async Task<IActionResult> AddFeed([FromBody] RssFeed feed)
        {
            await _rssFeedManager.AddFeedAsync(feed);
            return Ok(feed);
        }

        [HttpPut("{id}")]
        public async Task<IActionResult> UpdateFeed(string id, [FromBody] RssFeed feed)
        {
            if (id != feed.Id)
            {
                return BadRequest("Feed ID mismatch");
            }

            await _rssFeedManager.UpdateFeedAsync(feed);
            return Ok(feed);
        }

        [HttpDelete("{id}")]
        public async Task<IActionResult> DeleteFeed(string id)
        {
            await _rssFeedManager.RemoveFeedAsync(id);
            return Ok();
        }

        [HttpPost("refresh")]
        public async Task<IActionResult> RefreshFeeds()
        {
            await _rssFeedManager.RefreshFeedsAsync(HttpContext.RequestAborted);
            return Ok(new { success = true });
        }

        [HttpPost("download/{id}")]
        public async Task<IActionResult> DownloadItem(string id)
        {
            await _rssFeedManager.MarkItemAsDownloadedAsync(id);
            return Ok(new { success = true });
        }
    }
}